@@ -20,15 +20,11 @@
 """Base package for application launching and environment management."""
 
 from autopilot.application._launcher import (
-    ClickApplicationLauncher,
     get_application_launcher_wrapper,
     NormalApplicationLauncher,
-    UpstartApplicationLauncher,
 )
 
 __all__ = [
-    'ClickApplicationLauncher',
     'NormalApplicationLauncher',
-    'UpstartApplicationLauncher',
     'get_application_launcher_wrapper',
 ]
