@@ -39,6 +39,7 @@ from autopilot.introspection.backends import WireProtocolVersionMismatch
 from autopilot.introspection.utilities import (
     _get_bus_connections_pid,
     _pid_is_running,
+    process_util,
 )
 from autopilot.utilities import deprecated
 
@@ -194,6 +195,29 @@ def get_proxy_object_for_existing_process(**kwargs):
     )
 
 
+def get_proxy_object_for_existing_process_by_name(
+        process_name,
+        emulator_base=None
+):
+    """Return the proxy object for a process by its name.
+
+    :param process_name: name of the process to get proxy object.
+        This must be a string.
+
+    :param emulator_base: emulator base to use with the custom proxy object.
+
+    :raises ValueError: if process not running or more than one PIDs
+        associated with the process.
+
+    :return: proxy object for the requested process.
+    """
+    pid = process_util.get_pid_for_process(process_name)
+    return get_proxy_object_for_existing_process(
+        pid=pid,
+        emulator_base=emulator_base
+    )
+
+
 def _map_connection_to_pid(connection, dbus_bus):
     try:
         return _get_bus_connections_pid(dbus_bus, connection)
