@@ -57,9 +57,7 @@ from testtools.testcase import _ExpectedFailure
 from unittest.case import SkipTest
 
 from autopilot.application import (
-    ClickApplicationLauncher,
     NormalApplicationLauncher,
-    UpstartApplicationLauncher,
 )
 from autopilot.display import Display, get_screenshot_data
 from autopilot.globals import get_debug_profile_fixture, get_test_timeout
@@ -285,78 +283,6 @@ class AutopilotTestCase(TestWithScenarios, TestCase, KeybindingsHelper):
         )
         return launcher.launch(application, arguments, **launch_args)
 
-    def launch_click_package(self, package_id, app_name=None, app_uris=[],
-                             **kwargs):
-        """Launch a click package application with introspection enabled.
-
-        This method takes care of launching a click package with introspection
-        exabled. You probably want to use this method if your application is
-        packaged in a click application, or is started via upstart.
-
-        Usage is similar to the
-        :py:meth:`AutopilotTestCase.launch_test_application`::
-
-            app_proxy = self.launch_click_package(
-                "com.ubuntu.dropping-letters"
-            )
-
-        :param package_id: The Click package name you want to launch. For
-            example: ``com.ubuntu.dropping-letters``
-        :param app_name: Currently, only one application can be packaged in a
-            click package, and this parameter can be left at None. If
-            specified, it should be the application name you wish to launch.
-        :param app_uris: Parameters used to launch the click package. This
-            parameter will be left empty if not used.
-
-        :keyword emulator_base: If set, specifies the base class to be used for
-            all emulators for this loaded application.
-
-        :raises RuntimeError: If the specified package_id cannot be found in
-            the click package manifest.
-        :raises RuntimeError: If the specified app_name cannot be found within
-            the specified click package.
-
-        :returns: proxy object for the launched package application
-
-        """
-        launcher = self.useFixture(
-            ClickApplicationLauncher(
-                case_addDetail=self.addDetailUniqueName,
-                **kwargs
-            )
-        )
-        return launcher.launch(package_id, app_name, app_uris)
-
-    def launch_upstart_application(self, application_name, uris=[],
-                                   launcher_class=UpstartApplicationLauncher,
-                                   **kwargs):
-        """Launch an application with upstart.
-
-        This method launched an application via the ``ubuntu-app-launch``
-        library, on platforms that support it.
-
-        Usage is similar to the
-        :py:meth:`AutopilotTestCase.launch_test_application`::
-
-            app_proxy = self.launch_upstart_application("gallery-app")
-
-        :param application_name: The name of the application to launch.
-        :param launcher_class: The application launcher class to use. Useful if
-        you need to overwrite the default to do something custom (i.e. using
-          AlreadyLaunchedUpstartLauncher)
-        :keyword emulator_base: If set, specifies the base class to be used for
-            all emulators for this loaded application.
-
-        :raises RuntimeError: If the specified application cannot be launched.
-        """
-        launcher = self.useFixture(
-            launcher_class(
-                case_addDetail=self.addDetailUniqueName,
-                **kwargs
-            )
-        )
-        return launcher.launch(application_name, uris)
-
     def _compare_system_with_app_snapshot(self):
         """Compare the currently running application with the last snapshot.
 
